@@ -1,7 +1,7 @@
 /* 
  * dist.c
  *
- * (c) 2008-2013  Klaus Schliep (klaus.schliep@gmail.com)
+ * (c) 2008-2015  Klaus Schliep (klaus.schliep@gmail.com)
  * 
  * 
  * This code may be distributed under the GNU GPL
@@ -95,21 +95,6 @@ SEXP sankoffQuartet(SEXP dat, SEXP sn, SEXP scost, SEXP sk){
     return(result);        
 }    
 
-/*
-SEXP sankoffTwin(SEXP dat1, SEXP dat2, SEXP sn, SEXP scost, SEXP sk){
-    int j, n=INTEGER(sn)[0], k = INTEGER(sk)[0];  
-    double *cost, *tmp;
-    SEXP result;
-    PROTECT(result = allocMatrix(REALSXP, n, k));
-    tmp = REAL(result);
-    PROTECT(scost = coerceVector(scost, REALSXP));
-    cost = REAL(scost);
-    for(j=0; j<(n*k); j++) tmp[j] = REAL(dat1)[j];
-    sankoff4(REAL(dat2), n, cost, k, tmp);
-    UNPROTECT(2);    
-    return(result);        
-} 
-*/
 
 SEXP sankoff3(SEXP dlist, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge, SEXP mNodes, SEXP tips){
     R_len_t i, n = length(node), nt = length(tips);
@@ -147,6 +132,7 @@ SEXP sankoff3(SEXP dlist, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge, SE
 }
 
 
+
 void sankoffTips(int *x, double *tmp, int nr, int nc, int nrs, double *result){
     int i, j;
     for(i = 0; i < (nr); i++){ 
@@ -154,19 +140,8 @@ void sankoffTips(int *x, double *tmp, int nr, int nc, int nrs, double *result){
     }
 }
 
-// faster und memory efficient, aehnlich wie logLik2
-//SEXP sankoff3(SEXP dlist, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge, SEXP mNodes, SEXP tips)
-/*
- * 
-library(phangorn) 
-data(Laurasiatherian)
-tree = NJ(dist.hamming(Laurasiatherian))
-sankoffNew(tree, Laurasiatherian)
- 
- */
-
-
 
+// sankoffNew
 SEXP sankoff3B(SEXP dlist, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge, SEXP mNodes, SEXP tips, SEXP contrast, SEXP nrs){
     R_len_t i, n = length(node); //, nt = length(tips);
     int nrx=INTEGER(nr)[0], ncx=INTEGER(nc)[0], mn=INTEGER(mNodes)[0], nrc = INTEGER(nrs)[0];
@@ -209,7 +184,6 @@ SEXP sankoff3B(SEXP dlist, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge, S
     return(dlist2);
 }
 
-
     
 SEXP pNodes(SEXP data, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge){
     R_len_t n = length(node); 
@@ -248,84 +222,35 @@ SEXP pNodes(SEXP data, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge){
 }
 
 
-
-/*
-
-static double *data1;
-static double *weight;
-
-void sankoff_init(double *weights, int *nr, int *nc, int *nTips)
-{
-    int i;
-    data1 = (double *) calloc(*nr * *nc * *nTips, sizeof(double));
-    weight = (double *) calloc(*nr, sizeof(double));
-    for(i=0; i<*nr; i++)weight[i] = weights[i]; 
-}
-
-
-void sankoff_free(){
-    free(data1);
-    free(weight);
-}
-
-
-
-
-Ziel weniger memory und schneller
-
-static R_INLINE void sankoff4(double *dat, int n, double *cost, int k, double *result){
-    int i, j, h; 
-    double tmp[k], x;
-    for(i = 0; i < n; i++){
-        for(j = 0; j < k; j++){
-            for(h = 0; h< k; h++){tmp[h] = dat[i + h*n] + cost[h + j*k];}
-            x = tmp[0];
-            for(h = 1; h< k; h++) {if(tmp[h]<x) {x=tmp[h];}}
-            result[i+j*n] += x;
-        }                   
-    }        
-}    
-
-
-void sankoffTips(int *x, double *tmp, int nr, int nc, int nrs, double *result){
-    int i, j;
-    for(i = 0; i < (nr); i++){ 
-        for(j = 0; j < (nc); j++) result[i + j*(nr)] += tmp[x[i] - 1L + j*(nrs)];  
-    }
-}
-
-
-// mNodes raus
-// SEXP fuer verschiedene IO mit R
-// ohne zuviele SEXP definieren, Ausnahme dlist
-void SANKOFF4(SEXP dlist, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge, SEXP mNodes, SEXP tips, SEXP contrast, SEXP nrs){
-    R_len_t i, n = length(node), nt = length(tips);
-    int nTips = (int)length(tips), nii;
-    int nrx=INTEGER(nr)[0], ncx=INTEGER(nc)[0], nrc = INTEGER(nrs)[0];
-    int  ni, ei, j, *edges=INTEGER(edge), *nodes=INTEGER(node);
-    int rc = ncx*nrx;
-    double *cost, *tmp; 
-    tmp = (double *) R_alloc(ncx * nrc, sizeof(double)); 
+SEXP sankoffMPR(SEXP dlist, SEXP plist, SEXP scost, SEXP nr, SEXP nc, SEXP node, SEXP edge){
+    R_len_t i, n = length(node);
+    int nrx=INTEGER(nr)[0], ncx=INTEGER(nc)[0], n0;
+    int  ei, j, *nodes=INTEGER(node), *edges=INTEGER(edge);
+    SEXP result, dlist2; //tmp, 
+    double *res, *cost; // *rtmp,
     cost = REAL(scost);
-    sankoff4(REAL(contrast), nrc, cost, ncx, tmp); 
-    if(!isNewList(dlist)) error("'dlist' must be a list");
-    ni = 0L;     
-    for(i = 0; i < n; i++) {
-        ei = edges[i]; 
-        nii = (nodes[i]-nTips) * rc; 
-        if(ni == nodes[i]){            
-            if(ei < nt) sankoffTips(INTEGER(VECTOR_ELT(dlist,ei)), tmp, nrx, ncx, nrc, &data1[nii]);
-            else sankoff4(&data1[(ei-1L)*rc], nrx, cost, ncx, &data1[nii]);
-            }
-        else{          
-            ni = nodes[i];
-            for(j=0; j<rc; j++) data1[nii+j] = 0.0; 
-            if(ei < nt) sankoffTips(INTEGER(VECTOR_ELT(dlist,ei)), tmp, nrx, ncx, nrc, &data1[nii]);
-            else sankoff4(&data1[(ei-1L)*rc], nrx, cost, ncx, &data1[nii]); 
-            }
+    n0 = nodes[n-1L];
+    PROTECT(dlist2 = allocVector(VECSXP, n+1L));  
+    PROTECT(result = allocMatrix(REALSXP, nrx, ncx));
+    res = REAL(result);
+    for(j=0;j<(nrx*ncx);j++)res[j]=0.0;
+    for(j=n-1L; j>=0; j--) {
+        if(nodes[j]!=n0){
+            SET_VECTOR_ELT(dlist2, n0, result);
+            UNPROTECT(1); 
+            n0 = nodes[j];    
+            PROTECT(result = allocMatrix(REALSXP, nrx, ncx));
+            res = REAL(result);  
+            for(i=0; i<(nrx * ncx); i++) res[i] = 0.0;
+            sankoff4(REAL(VECTOR_ELT(plist,nodes[j])), nrx, cost, ncx, res);
+        }
+        ei = edges[j];
+        sankoff4(REAL(VECTOR_ELT(dlist,ei)), nrx, cost, ncx, res);
+   
     }
+    SET_VECTOR_ELT(dlist2, n0, result);
+    UNPROTECT(2); 
+    return(dlist2);
 }
 
-*/
-
 
